.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`core.completer`
=============================
.. automodule:: IPython.core.completer

.. currentmodule:: IPython.core.completer

5 Classes
---------

.. autoclass:: ProvisionalCompleterWarning
  :members:
  :show-inheritance:

.. autoclass:: Completion
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: CompletionSplitter
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: Completer
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: IPCompleter
  :members:
  :show-inheritance:

  .. automethod:: __init__

13 Functions
------------

.. autofunction:: IPython.core.completer.provisionalcompleter


.. autofunction:: IPython.core.completer.has_open_quotes


.. autofunction:: IPython.core.completer.protect_filename


.. autofunction:: IPython.core.completer.expand_user


.. autofunction:: IPython.core.completer.compress_user


.. autofunction:: IPython.core.completer.completions_sorting_key


.. autofunction:: IPython.core.completer.rectify_completions


.. autofunction:: IPython.core.completer.get__all__entries


.. autofunction:: IPython.core.completer.match_dict_keys


.. autofunction:: IPython.core.completer.cursor_to_position


.. autofunction:: IPython.core.completer.position_to_cursor


.. autofunction:: IPython.core.completer.back_unicode_name_matches


.. autofunction:: IPython.core.completer.back_latex_name_matches

